# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/nixtlats/',
                'doc_host': 'https://Nixtla.github.io',
                'git_url': 'https://github.com/Nixtla/nixtla/',
                'lib_path': 'nixtlats'},
  'syms': { 'nixtlats.client': {},
            'nixtlats.core.api_error': {},
            'nixtlats.core.client_wrapper': {},
            'nixtlats.core.datetime_utils': {},
            'nixtlats.core.jsonable_encoder': {},
            'nixtlats.core.remove_none_from_dict': {},
            'nixtlats.date_features': { 'nixtlats.date_features.CountryHolidays': ( 'date_features.html#countryholidays',
                                                                                    'nixtlats/date_features.py'),
                                        'nixtlats.date_features.CountryHolidays.__call__': ( 'date_features.html#countryholidays.__call__',
                                                                                             'nixtlats/date_features.py'),
                                        'nixtlats.date_features.CountryHolidays.__init__': ( 'date_features.html#countryholidays.__init__',
                                                                                             'nixtlats/date_features.py'),
                                        'nixtlats.date_features.CountryHolidays.__name__': ( 'date_features.html#countryholidays.__name__',
                                                                                             'nixtlats/date_features.py'),
                                        'nixtlats.date_features.SpecialDates': ( 'date_features.html#specialdates',
                                                                                 'nixtlats/date_features.py'),
                                        'nixtlats.date_features.SpecialDates.__call__': ( 'date_features.html#specialdates.__call__',
                                                                                          'nixtlats/date_features.py'),
                                        'nixtlats.date_features.SpecialDates.__init__': ( 'date_features.html#specialdates.__init__',
                                                                                          'nixtlats/date_features.py'),
                                        'nixtlats.date_features.SpecialDates.__name__': ( 'date_features.html#specialdates.__name__',
                                                                                          'nixtlats/date_features.py'),
                                        'nixtlats.date_features._get_holidays_df': ( 'date_features.html#_get_holidays_df',
                                                                                     'nixtlats/date_features.py'),
                                        'nixtlats.date_features._transform_dict_holidays': ( 'date_features.html#_transform_dict_holidays',
                                                                                             'nixtlats/date_features.py')},
            'nixtlats.distributed.timegpt': { 'nixtlats.distributed.timegpt._DistributedTimeGPT': ( 'distributed.timegpt.html#_distributedtimegpt',
                                                                                                    'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT.__init__': ( 'distributed.timegpt.html#_distributedtimegpt.__init__',
                                                                                                             'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._cross_validation': ( 'distributed.timegpt.html#_distributedtimegpt._cross_validation',
                                                                                                                      'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._detect_anomalies': ( 'distributed.timegpt.html#_distributedtimegpt._detect_anomalies',
                                                                                                                      'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._distribute_method': ( 'distributed.timegpt.html#_distributedtimegpt._distribute_method',
                                                                                                                       'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._forecast': ( 'distributed.timegpt.html#_distributedtimegpt._forecast',
                                                                                                              'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._forecast_x': ( 'distributed.timegpt.html#_distributedtimegpt._forecast_x',
                                                                                                                'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._get_anomalies_schema': ( 'distributed.timegpt.html#_distributedtimegpt._get_anomalies_schema',
                                                                                                                          'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._get_forecast_schema': ( 'distributed.timegpt.html#_distributedtimegpt._get_forecast_schema',
                                                                                                                         'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._instantiate_timegpt': ( 'distributed.timegpt.html#_distributedtimegpt._instantiate_timegpt',
                                                                                                                         'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT.cross_validation': ( 'distributed.timegpt.html#_distributedtimegpt.cross_validation',
                                                                                                                     'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT.detect_anomalies': ( 'distributed.timegpt.html#_distributedtimegpt.detect_anomalies',
                                                                                                                     'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT.forecast': ( 'distributed.timegpt.html#_distributedtimegpt.forecast',
                                                                                                             'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._cotransform': ( 'distributed.timegpt.html#_cotransform',
                                                                                             'nixtlats/distributed/timegpt.py')},
            'nixtlats.errors.unprocessable_entity_error': {},
            'nixtlats.timegpt': { 'nixtlats.timegpt.TimeGPT': ('timegpt.html#timegpt', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt.TimeGPT._instantiate_distributed_timegpt': ( 'timegpt.html#timegpt._instantiate_distributed_timegpt',
                                                                                                 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt.TimeGPT.cross_validation': ( 'timegpt.html#timegpt.cross_validation',
                                                                                 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt.TimeGPT.detect_anomalies': ( 'timegpt.html#timegpt.detect_anomalies',
                                                                                 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt.TimeGPT.forecast': ('timegpt.html#timegpt.forecast', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT': ('timegpt.html#_timegpt', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT.__init__': ('timegpt.html#_timegpt.__init__', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT._cross_validation': ( 'timegpt.html#_timegpt._cross_validation',
                                                                                   'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT._detect_anomalies': ( 'timegpt.html#_timegpt._detect_anomalies',
                                                                                   'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT._forecast': ('timegpt.html#_timegpt._forecast', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT.plot': ('timegpt.html#_timegpt.plot', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT.validate_token': ( 'timegpt.html#_timegpt.validate_token',
                                                                                'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel': ('timegpt.html#_timegptmodel', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.__init__': ('timegpt.html#_timegptmodel.__init__', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel._call_api': ( 'timegpt.html#_timegptmodel._call_api',
                                                                                'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel._retry_strategy': ( 'timegpt.html#_timegptmodel._retry_strategy',
                                                                                      'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.add_date_features': ( 'timegpt.html#_timegptmodel.add_date_features',
                                                                                        'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.compute_date_feature': ( 'timegpt.html#_timegptmodel.compute_date_feature',
                                                                                           'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.cross_validation': ( 'timegpt.html#_timegptmodel.cross_validation',
                                                                                       'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.dataframes_to_dict': ( 'timegpt.html#_timegptmodel.dataframes_to_dict',
                                                                                         'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.detect_anomalies': ( 'timegpt.html#_timegptmodel.detect_anomalies',
                                                                                       'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.forecast': ('timegpt.html#_timegptmodel.forecast', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.infer_freq': ( 'timegpt.html#_timegptmodel.infer_freq',
                                                                                 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.make_future_dataframe': ( 'timegpt.html#_timegptmodel.make_future_dataframe',
                                                                                            'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.preprocess_X_df': ( 'timegpt.html#_timegptmodel.preprocess_x_df',
                                                                                      'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.preprocess_dataframes': ( 'timegpt.html#_timegptmodel.preprocess_dataframes',
                                                                                            'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.resample_dataframe': ( 'timegpt.html#_timegptmodel.resample_dataframe',
                                                                                         'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.set_model_params': ( 'timegpt.html#_timegptmodel.set_model_params',
                                                                                       'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.transform_inputs': ( 'timegpt.html#_timegptmodel.transform_inputs',
                                                                                       'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.transform_outputs': ( 'timegpt.html#_timegptmodel.transform_outputs',
                                                                                        'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.validate_input_size': ( 'timegpt.html#_timegptmodel.validate_input_size',
                                                                                          'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt.validate_model_parameter': ( 'timegpt.html#validate_model_parameter',
                                                                                 'nixtlats/timegpt.py')},
            'nixtlats.types.http_validation_error': {},
            'nixtlats.types.multi_series_input': {},
            'nixtlats.types.single_series_forecast': {},
            'nixtlats.types.validation_error': {},
            'nixtlats.types.validation_error_loc_item': {},
            'nixtlats.utils': {'nixtlats.utils.colab_badge': ('utils.html#colab_badge', 'nixtlats/utils.py')}}}
